@@ -12,15 +12,14 @@
 //! [guide to enabling interactivity 🔗]: https://api.slack.com/interactivity/handling
 
 // mod builder;
-// pub mod conversation;
+pub mod conversation;
 pub mod external;
 // pub mod public_channel;
 pub mod static_;
 pub mod user;
 
-// #[doc(inline)]
-// pub use conversation::Conversation;
-
+#[doc(inline)]
+pub use conversation::Conversation;
 #[doc(inline)]
 pub use external::External;
 // #[doc(inline)]
